package com.huiju.estateagents.eContract.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fadada.sdk.client.FddClientBase;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.bo.request.ContractRecordRequestBO;
import com.huiju.estateagents.config.FadadaProperties;
import com.huiju.estateagents.eContract.entity.TaContract;
import com.huiju.estateagents.eContract.entity.TaContractBusiness;
import com.huiju.estateagents.eContract.mapper.TaContractMapper;
import com.huiju.estateagents.eContract.service.ITaContractService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.entity.TaRaiseRecord;
import com.huiju.estateagents.mapper.TaOrgMapper;
import com.huiju.estateagents.mapper.TaRaiseRecordMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.Map;

/**
 * <p>
 * 合同列表  服务实现类
 * </p>
 *
 * @author fxf
 * @since 2020-03-26
 */
@Service
@Slf4j
public class TaContractServiceImpl extends ServiceImpl<TaContractMapper, TaContract> implements ITaContractService {

    @Autowired
    private FadadaProperties fadadaProperties;

    @Autowired
    private TaContractMapper taContractMapper;

    @Autowired
    private TaRaiseRecordMapper taRaiseRecordMapper;

    @Autowired
    private TaOrgMapper taOrgMapper;

    @Override
    public ResponseBean listContractForAdmin(Integer pageNum, Integer pageSize, String contractName, Boolean archives, String signatoryName, Integer signatoryStatus, String customerName, Integer customerStatus, LocalDate archivesStartDate, LocalDate archivesEndDate, Integer orgId) {

        ResponseBean responseBean = new ResponseBean();
        IPage<TaContract> pg = new Page<>(pageNum, pageSize);
        pg = taContractMapper.listContractForAdmin(pg, contractName, archives, signatoryName, signatoryStatus, customerName, customerStatus, archivesStartDate, archivesEndDate, orgId);
        responseBean.addSuccess(pg);
        return responseBean;
    }

    @Override
    public ResponseBean listContractForChannel(ContractRecordRequestBO requestBO) {
        log.info("TaContractServiceImpl.listContractForChannel 接收参数:{}", JSONObject.toJSONString(requestBO));

        ResponseBean responseBean = new ResponseBean();

        IPage<TaContract> pg = new Page<>(requestBO.getPageNum(), requestBO.getPageSize());
        pg = taContractMapper.listContractForChannel(pg, requestBO);
        responseBean.addSuccess(pg);
        return responseBean;
    }

    /**
     * 企业自动签署合同
     *
     * @param taRaiseRecord
     * @param person
     * @return
     */
    @Override
    @Transactional
    public TaContract autoContract(TaRaiseRecord taRaiseRecord, TaPerson person) {
        taRaiseRecord = taRaiseRecordMapper.selectById(taRaiseRecord.getRaiseRecordId());

        //根据raiseId获取合同的所有参数
        TaContractBusiness taContractBusiness = taContractMapper.selectContractInfoByRaiseId(taRaiseRecord.getRaiseId());

        //先入合同表
        TaContract taContract = new TaContract();
        taContract.setBuildingId(taRaiseRecord.getBuildingId());
        taContract.setOrgId(taRaiseRecord.getOrgId());
        taContract.setOrgName(taOrgMapper.selectById(taRaiseRecord.getOrgId()).getName());
        taContract.setTargetType("raise");
        taContract.setTargetId(Integer.valueOf(taRaiseRecord.getRaiseId()));
        taContract.setInvoiceTargetType("raise_record");
        taContract.setInvoiceTargetId(taRaiseRecord.getRaiseRecordId());
        taContract.setCompanyId(taContractBusiness.getCompanyId());
        taContract.setCreateDate(LocalDateTime.now());
        taContractMapper.insert(taContract);

        FddClientBase base = new FddClientBase(fadadaProperties.getAppId(),fadadaProperties.getAppSecret(),fadadaProperties.getVersion(),fadadaProperties.getServeHost());
        String result = base.invokeUploadDocs(taContract.getContractId().toString(), taContractBusiness.getContractTemplateName(), null, taContractBusiness.getContractTemplateAddress(), ".pdf");
        return null;
    }
}
